define(["require", "exports", "@essential-projects/http_node", "@process-engine/consumer_api_contracts", "async-middleware", "./middlewares/index"], function (require, exports, http_node_1, consumer_api_contracts_1, async_middleware_1, index_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    class ConsumerApiRouter extends http_node_1.BaseRouter {
        constructor(consumerApiRestController, identityService) {
            super();
            this.consumerApiRestController = consumerApiRestController;
            this.identityService = identityService;
        }
        get baseRoute() {
            return 'api/consumer/v1';
        }
        async initializeRouter() {
            this.registerMiddlewares();
            this.registerProcessModelRoutes();
            this.registerEventRoutes();
            this.registerEmptyActivityRoutes();
            this.registerUserTaskRoutes();
            this.registerManualTaskRoutes();
        }
        registerMiddlewares() {
            const resolveIdentity = index_1.createResolveIdentityMiddleware(this.identityService);
            this.router.use(async_middleware_1.wrap(resolveIdentity));
        }
        registerProcessModelRoutes() {
            const controller = this.consumerApiRestController;
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModels, async_middleware_1.wrap(controller.getProcessModels.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelById, async_middleware_1.wrap(controller.getProcessModelById.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelByProcessInstanceId, async_middleware_1.wrap(controller.getProcessModelByProcessInstanceId.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.getProcessResultForCorrelation, async_middleware_1.wrap(controller.getProcessResultForCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.getOwnProcessInstances, async_middleware_1.wrap(controller.getProcessInstancesByIdentity.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.startProcessInstance, async_middleware_1.wrap(controller.startProcessInstance.bind(controller)));
        }
        registerEventRoutes() {
            const controller = this.consumerApiRestController;
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelEvents, async_middleware_1.wrap(controller.getEventsForProcessModel.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.correlationEvents, async_middleware_1.wrap(controller.getEventsForCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelCorrelationEvents, async_middleware_1.wrap(controller.getEventsForProcessModelInCorrelation.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.triggerMessageEvent, async_middleware_1.wrap(controller.triggerMessageEvent.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.triggerSignalEvent, async_middleware_1.wrap(controller.triggerSignalEvent.bind(controller)));
        }
        registerEmptyActivityRoutes() {
            const controller = this.consumerApiRestController;
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelEmptyActivities, async_middleware_1.wrap(controller.getEmptyActivitiesForProcessModel.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processInstanceEmptyActivities, async_middleware_1.wrap(controller.getEmptyActivitiesForProcessInstance.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.correlationEmptyActivities, async_middleware_1.wrap(controller.getEmptyActivitiesForCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelCorrelationEmptyActivities, async_middleware_1.wrap(controller.getEmptyActivitiesForProcessModelInCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.getOwnEmptyActivities, async_middleware_1.wrap(controller.getWaitingEmptyActivitiesByIdentity.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishEmptyActivity, async_middleware_1.wrap(controller.finishEmptyActivity.bind(controller)));
        }
        registerUserTaskRoutes() {
            const controller = this.consumerApiRestController;
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelUserTasks, async_middleware_1.wrap(controller.getUserTasksForProcessModel.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processInstanceUserTasks, async_middleware_1.wrap(controller.getUserTasksForProcessInstance.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.correlationUserTasks, async_middleware_1.wrap(controller.getUserTasksForCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelCorrelationUserTasks, async_middleware_1.wrap(controller.getUserTasksForProcessModelInCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.getOwnUserTasks, async_middleware_1.wrap(controller.getWaitingUserTasksByIdentity.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishUserTask, async_middleware_1.wrap(controller.finishUserTask.bind(controller)));
        }
        registerManualTaskRoutes() {
            const controller = this.consumerApiRestController;
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelManualTasks, async_middleware_1.wrap(controller.getManualTasksForProcessModel.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processInstanceManualTasks, async_middleware_1.wrap(controller.getManualTasksForProcessInstance.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.correlationManualTasks, async_middleware_1.wrap(controller.getManualTasksForCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.processModelCorrelationManualTasks, async_middleware_1.wrap(controller.getManualTasksForProcessModelInCorrelation.bind(controller)));
            this.router.get(consumer_api_contracts_1.restSettings.paths.getOwnManualTasks, async_middleware_1.wrap(controller.getWaitingManualTasksByIdentity.bind(controller)));
            this.router.post(consumer_api_contracts_1.restSettings.paths.finishManualTask, async_middleware_1.wrap(controller.finishManualTask.bind(controller)));
        }
    }
    exports.ConsumerApiRouter = ConsumerApiRouter;
});
//# sourceMappingURL=consumer_api_router.js.map