"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const consumer_api_contracts_1 = require("@process-engine/consumer_api_contracts");
class ConsumerApiController {
    constructor(consumerApiService) {
        this.httpCodeSuccessfulResponse = 200;
        this.httpCodeSuccessfulNoContentResponse = 204;
        this.consumerApiService = consumerApiService;
    }
    async getProcessModels(request, response) {
        const identity = request.identity;
        const result = await this.consumerApiService.getProcessModels(identity);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getProcessModelById(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getProcessModelById(identity, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getProcessModelByProcessInstanceId(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getProcessModelByProcessInstanceId(identity, processInstanceId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async startProcessInstance(request, response) {
        const processModelId = request.params.process_model_id;
        const startEventId = request.query.start_event_id;
        const endEventId = request.query.end_event_id;
        const payload = request.body;
        let startCallbackType = Number.parseInt(request.query.start_callback_type);
        if (!startCallbackType) {
            startCallbackType = consumer_api_contracts_1.DataModels.ProcessModels.StartCallbackType.CallbackOnProcessInstanceCreated;
        }
        const identity = request.identity;
        const result = await this.consumerApiService.startProcessInstance(identity, processModelId, payload, startCallbackType, startEventId, endEventId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getProcessResultForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getProcessResultForCorrelation(identity, correlationId, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getProcessInstancesByIdentity(request, response) {
        const identity = request.identity;
        const result = await this.consumerApiService.getProcessInstancesByIdentity(identity);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    // event-routes
    async getEventsForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEventsForProcessModel(identity, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEventsForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEventsForCorrelation(identity, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEventsForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEventsForProcessModelInCorrelation(identity, processModelId, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async triggerMessageEvent(request, response) {
        const eventName = request.params.event_name;
        const payload = request.body;
        const identity = request.identity;
        await this.consumerApiService.triggerMessageEvent(identity, eventName, payload);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    async triggerSignalEvent(request, response) {
        const eventName = request.params.event_name;
        const payload = request.body;
        const identity = request.identity;
        await this.consumerApiService.triggerSignalEvent(identity, eventName, payload);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    // empty-activity-routes
    async getEmptyActivitiesForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEmptyActivitiesForProcessModel(identity, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForProcessInstance(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEmptyActivitiesForProcessInstance(identity, processInstanceId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEmptyActivitiesForCorrelation(identity, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getEmptyActivitiesForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getEmptyActivitiesForProcessModelInCorrelation(identity, processModelId, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getWaitingEmptyActivitiesByIdentity(request, response) {
        const identity = request.identity;
        const result = await this.consumerApiService.getWaitingEmptyActivitiesByIdentity(identity);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async finishEmptyActivity(request, response) {
        const identity = request.identity;
        const processInstanceId = request.params.process_instance_id;
        const correlationId = request.params.correlation_id;
        const emptyActivityInstanceId = request.params.empty_activity_instance_id;
        await this.consumerApiService.finishEmptyActivity(identity, processInstanceId, correlationId, emptyActivityInstanceId);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    // user-task-routes
    async getUserTasksForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getUserTasksForProcessModel(identity, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getUserTasksForProcessInstance(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getUserTasksForProcessInstance(identity, processInstanceId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getUserTasksForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getUserTasksForCorrelation(identity, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getUserTasksForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getUserTasksForProcessModelInCorrelation(identity, processModelId, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getWaitingUserTasksByIdentity(request, response) {
        const identity = request.identity;
        const result = await this.consumerApiService.getWaitingUserTasksByIdentity(identity);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async finishUserTask(request, response) {
        const identity = request.identity;
        const processInstanceId = request.params.process_instance_id;
        const correlationId = request.params.correlation_id;
        const userTaskInstanceId = request.params.user_task_instance_id;
        const userTaskResult = request.body;
        await this.consumerApiService.finishUserTask(identity, processInstanceId, correlationId, userTaskInstanceId, userTaskResult);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
    // manual-task-routes
    async getManualTasksForProcessModel(request, response) {
        const processModelId = request.params.process_model_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getManualTasksForProcessModel(identity, processModelId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForProcessInstance(request, response) {
        const processInstanceId = request.params.process_instance_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getManualTasksForProcessInstance(identity, processInstanceId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForCorrelation(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getManualTasksForCorrelation(identity, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getManualTasksForProcessModelInCorrelation(request, response) {
        const processModelId = request.params.process_model_id;
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const result = await this.consumerApiService.getManualTasksForProcessModelInCorrelation(identity, processModelId, correlationId);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async getWaitingManualTasksByIdentity(request, response) {
        const identity = request.identity;
        const result = await this.consumerApiService.getWaitingManualTasksByIdentity(identity);
        response.status(this.httpCodeSuccessfulResponse).json(result);
    }
    async finishManualTask(request, response) {
        const correlationId = request.params.correlation_id;
        const identity = request.identity;
        const processInstanceId = request.params.process_instance_id;
        const manualTaskInstanceId = request.params.manual_task_instance_id;
        await this.consumerApiService.finishManualTask(identity, processInstanceId, correlationId, manualTaskInstanceId);
        response.status(this.httpCodeSuccessfulNoContentResponse).send();
    }
}
exports.ConsumerApiController = ConsumerApiController;
//# sourceMappingURL=consumer_api_controller.js.map